package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DERSequence;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Vector;

public class ExtendedKeyUsage extends ASN1Encodable {
   Hashtable usageTable;
   ASN1Sequence seq;

   public static ExtendedKeyUsage getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static ExtendedKeyUsage getInstance(Object obj) {
      if (obj instanceof ExtendedKeyUsage) {
         return (ExtendedKeyUsage)obj;
      } else if (obj instanceof ASN1Sequence) {
         return new ExtendedKeyUsage((ASN1Sequence)obj);
      } else if (obj instanceof X509Extension) {
         return getInstance(X509Extension.convertValueToObject((X509Extension)obj));
      } else {
         throw new IllegalArgumentException("Invalid ExtendedKeyUsage: " + obj.getClass().getName());
      }
   }

   public ExtendedKeyUsage(KeyPurposeId usage) {
      this.usageTable = new Hashtable();
      this.seq = new DERSequence(usage);
      this.usageTable.put(usage, usage);
   }

   public ExtendedKeyUsage(ASN1Sequence seq) {
      Hashtable var2;
      var2 = new Hashtable.<init>();
      this.usageTable = var2;
      this.seq = seq;
      Enumeration seq1 = seq.getObjects();

      while(seq1.hasMoreElements()) {
         Object var4;
         if (!((var4 = seq1.nextElement()) instanceof DERObjectIdentifier)) {
            throw new IllegalArgumentException("Only DERObjectIdentifiers allowed in ExtendedKeyUsage.");
         }

         this.usageTable.put(var4, var4);
      }

   }

   public ExtendedKeyUsage(Vector usages) {
      Vector var10000 = usages;
      super();
      Hashtable usages1;
      usages1 = new Hashtable.<init>();
      this.usageTable = usages1;
      ASN1EncodableVector usages2;
      usages2 = new ASN1EncodableVector.<init>();
      Enumeration var2 = var10000.elements();

      while(var2.hasMoreElements()) {
         DERObject var3;
         usages2.add(var3 = (DERObject)var2.nextElement());
         this.usageTable.put(var3, var3);
      }

      ExtendedKeyUsage var4 = this;
      DERSequence var5;
      var5 = new DERSequence.<init>(usages2);
      var4.seq = var5;
   }

   public boolean hasKeyPurposeId(KeyPurposeId keyPurposeId) {
      return this.usageTable.get(keyPurposeId) != null;
   }

   public Vector getUsages() {
      ExtendedKeyUsage var10000 = this;
      Vector var2;
      var2 = new Vector.<init>();
      Enumeration var1 = var10000.usageTable.elements();

      while(var1.hasMoreElements()) {
         var2.addElement(var1.nextElement());
      }

      return var2;
   }

   public int size() {
      return this.usageTable.size();
   }

   public DERObject toASN1Object() {
      return this.seq;
   }
}
